@@ -3,6 +3,7 @@
 import json
 
 from ..common.base import Base
+from ..common.config import *
 
 
 class DataGroupApi(Base):
@@ -22,13 +23,20 @@ class DataGroupApi(Base):
         api_url = self.__get_api_url(data_group_id)
         return self.api_get(api_url, params={})
 
-    def get_all_data_groups_by_name_api(self, name):
+    def get_all_data_groups_by_name_api(self, name, page=DEF_PAGE,
+                                        page_size=DEF_PAGE_SIZE):
         api_url = self.__get_api_url()
-        return self.api_get(api_url, params={'name': name})
+        return self.api_get(api_url, params={'name': name,
+                                             'page': page,
+                                             'page_size': page_size})
 
-    def get_all_data_groups_by_experiment_id_api(self, experiment_id):
+    def get_all_data_groups_by_experiment_id_api(self, experiment_id,
+                                                 page=DEF_PAGE,
+                                                 page_size=DEF_PAGE_SIZE):
         api_url = self.__get_api_url()
-        return self.api_get(api_url, params={'experiment_id': experiment_id})
+        return self.api_get(api_url, params={'experiment_id': experiment_id,
+                                             'page': page,
+                                             'page_size': page_size})
 
     #
     # Private Methods
