@@ -3,6 +3,7 @@
 import json
 
 from ..common.base import Base
+from ..common.config import *
 
 
 class RunApi(Base):
@@ -22,14 +23,20 @@ class RunApi(Base):
         api_url = self.__get_api_url(run_id)
         return self.api_get(api_url, params={})
 
-    def get_all_runs_by_run_number_api(self, run_number):
+    def get_all_runs_by_run_number_api(self, run_number,
+                                       page=DEF_PAGE, page_size=DEF_PAGE_SIZE):
         api_url = self.__get_api_url()
-        return self.api_get(api_url, params={'run_number': run_number})
+        return self.api_get(api_url, params={'run_number': run_number,
+                                             'page': page,
+                                             'page_size': page_size})
 
-    def get_all_runs_by_proposal_number_api(self, proposal_number):
+    def get_all_runs_by_proposal_number_api(self, proposal_number,
+                                            page=DEF_PAGE,
+                                            page_size=DEF_PAGE_SIZE):
         api_url = self.__get_api_url('runs_by_proposal')
         return self.api_get(api_url,
-                            params={'proposal_number': proposal_number})
+                            params={'proposal_number': proposal_number,
+                                    'page': page, 'page_size': page_size})
 
     def get_run_by_run_number_and_experiment_id_api(self,
                                                     run_number,
