@@ -8,7 +8,8 @@ from http import HTTPStatus
 from oauth2_xfel_client.oauth2_client_backend import Oauth2ClientBackend
 from oauthlib.oauth2 import TokenExpiredError
 
-from ..common.config import CREATE, DELETE, UPDATE, GET, SET
+from ..common.config import CREATE, DELETE, UPDATE, GET, SET, \
+    DEF_MAX_RETRIES, DEF_TIMEOUT, DEF_SSL_VERIFY
 
 
 def replace_expired_token(func):
@@ -46,14 +47,20 @@ class Base:
                  client_id, client_secret,
                  token_url, refresh_url, auth_url, scope,
                  user_email, base_api_url,
-                 session_token=None):
+                 session_token=None,
+                 max_retries=DEF_MAX_RETRIES,
+                 timeout=DEF_TIMEOUT,
+                 ssl_verify=DEF_SSL_VERIFY):
         self.oauth_client = Oauth2ClientBackend(client_id=client_id,
                                                 client_secret=client_secret,
                                                 scope=scope,
                                                 token_url=token_url,
                                                 refresh_url=refresh_url,
                                                 auth_url=auth_url,
-                                                session_token=session_token)
+                                                session_token=session_token,
+                                                max_retries=max_retries,
+                                                timeout=timeout,
+                                                ssl_verify=ssl_verify)
 
         self.headers = default_headers(user_email)
         # Ensure the base URL has a trailing slash
