@@ -14,6 +14,7 @@ from .modules import (
     DataFile, DataGroup, DataGroupRepository, DataGroupType,
     DataSourceGroup, DataSourceGroupVersion, Experiment,
     Instrument, Parameter, Proposal, Repository, Run, Sample)
+from .common.config import DEF_PAGE, DEF_PAGE_SIZE
 
 
 class MetadataClient(
@@ -22,8 +23,8 @@ class MetadataClient(
     ExperimentTypeApi, InstrumentApi, ParameterApi, ParameterTypeApi,
     DarkRunApi, ProposalApi, RepositoryApi, RunApi, SampleApi, UserApi
 ):
-    def get_all_xfel_instruments(self):
-        resp = Instrument.get_all_from_xfel(self)
+    def get_all_xfel_instruments(self, page=DEF_PAGE, page_size=DEF_PAGE_SIZE):
+        resp = Instrument.get_all_from_xfel(self, page, page_size)
 
         if not resp['success']:
             error_msg = '{0} >> {1}'.format(resp['info'], resp['app_info'])
@@ -31,8 +32,8 @@ class MetadataClient(
 
         return resp
 
-    def get_all_data_group_types(self):
-        resp = DataGroupType.get_all(self)
+    def get_all_data_group_types(self, page=DEF_PAGE, page_size=DEF_PAGE_SIZE):
+        resp = DataGroupType.get_all(self, page, page_size)
 
         if not resp['success']:
             error_msg = '{0} >> {1}'.format(resp['info'], resp['app_info'])
@@ -88,7 +89,8 @@ class MetadataClient(
         return resp
 
     def get_proposal_runs(self, proposal_number,
-                          run_number=None, page=1, page_size=100):
+                          run_number=None, page=DEF_PAGE,
+                          page_size=DEF_PAGE_SIZE):
         logging.debug('proposal_number: {0}'.format(proposal_number))
 
         # Get PROPOSAL #id from #number
@@ -117,7 +119,8 @@ class MetadataClient(
         resp = Experiment.get_all_by_proposal_id(self, proposal_id)
         return resp
 
-    def get_proposal_samples(self, proposal_number, page=1, page_size=100):
+    def get_proposal_samples(self, proposal_number, page=DEF_PAGE,
+                             page_size=DEF_PAGE_SIZE):
         logging.debug('proposal_number: {0}'.format(proposal_number))
 
         # Get PROPOSAL #id from #number
@@ -129,7 +132,8 @@ class MetadataClient(
 
         proposal_id = resp['data']['id']
         logging.debug('proposal_id: {0}'.format(proposal_id))
-        resp = Sample.get_all_by_proposal_id(self, proposal_id, page, page_size)
+        resp = Sample.get_all_by_proposal_id(self, proposal_id,
+                                             page, page_size)
         return resp
 
     def register_run(self, experiment_id, sample_id,
