@@ -93,7 +93,8 @@ class Sample:
 
     @staticmethod
     def get_all_by_name_and_proposal_id(mdc_client, name, proposal_id,
-                                        page=1, page_size=100):
+                                        page=DEF_PAGE,
+                                        page_size=DEF_PAGE_SIZE):
         response = mdc_client.get_all_samples_by_name_and_proposal_id_api(
             name, proposal_id, page, page_size)
 
@@ -102,9 +103,10 @@ class Sample:
         return Base.format_response(response, GET, OK, MODULE_NAME)
 
     @staticmethod
-    def get_all_by_proposal_id(mdc_client, proposal_id, page=1, page_size=100):
-        resp = mdc_client.get_all_samples_by_proposal_id_api(proposal_id,
-                                                             page, page_size)
+    def get_all_by_proposal_id(mdc_client, proposal_id, page=DEF_PAGE,
+                               page_size=DEF_PAGE_SIZE):
+        resp = mdc_client.get_all_samples_by_proposal_id_api(
+            proposal_id, page, page_size)
 
         curr_method_name = inspect.currentframe().f_code.co_name
         Base.cal_debug(MODULE_NAME, curr_method_name, resp)
@@ -112,12 +114,9 @@ class Sample:
 
     @staticmethod
     def get_by_name_and_proposal_id(mdc_client, name, proposal_id,
-                                    page=1, page_size=100):
-        res = Sample.get_all_by_name_and_proposal_id(mdc_client,
-                                                     name,
-                                                     proposal_id,
-                                                     page,
-                                                     page_size)
+                                    page=DEF_PAGE, page_size=DEF_PAGE_SIZE):
+        res = Sample.get_all_by_name_and_proposal_id(
+            mdc_client, name, proposal_id, page, page_size)
 
         if res['success']:
             res = Base.unique_key_format_result(res=res,
