@@ -38,8 +38,7 @@ class DarkRunApiTest(ApiBase, unittest.TestCase):
                 'flg_status': 'R',
                 # 'pdu_karabo_das': ['t1', 't2'],
                 'size': '',
-                'calcat_url': '',
-                'globus_url': '',
+                'report_url': '',
                 'input_path': '',
                 'output_path': '',
                 'calcat_feedback': '',
@@ -80,8 +79,7 @@ class DarkRunApiTest(ApiBase, unittest.TestCase):
         self.assert_eq_hfield(receive, expect,
                               'operation_mode_identifier', STRING)
         self.assert_eq_hfield(receive, expect, 'size', STRING)
-        self.assert_eq_hfield(receive, expect, 'calcat_url', STRING)
-        self.assert_eq_hfield(receive, expect, 'globus_url', STRING)
+        self.assert_eq_hfield(receive, expect, 'report_url', STRING)
         self.assert_eq_hfield(receive, expect, 'input_path', STRING)
         self.assert_eq_hfield(receive, expect, 'output_path', STRING)
         self.assert_eq_hfield(receive, expect, 'calcat_feedback', STRING)
