@@ -57,7 +57,9 @@ class DataFileTest(ModuleBase, unittest.TestCase):
         # Get entry by data_group_id
         #
         result3 = DataFile.get_all_by_data_group_id(self.mdc_client,
-                                                    data_file_data_group_id)
+                                                    data_file_data_group_id,
+                                                    page=DEF_PAGE,
+                                                    page_size=DEF_PAGE_SIZE)
 
         expected_result = [self.data_file_01]
         self.assert_find_success(MODULE_NAME, result3, expected_result)
