@@ -144,7 +144,7 @@ class SampleTest(ModuleBase, unittest.TestCase):
         #
         result10 = Sample.get_all_by_proposal_id(self.mdc_client,
                                                  sample_proposal_id,
-                                                 page=1, page_size=2)
+                                                 page=DEF_PAGE, page_size=2)
 
         expected_result = [
             {'id': -1,
